<?php 
/**
 * Plugin Name: Archive Site (Matomo Plugin)
 * Plugin URI: http://plugins.matomo.org/ArchiveSite
 * Description: Start archiving process via web.
 * Author: iMarkus, hagor
 * Author URI: https://github.com/iMarkus/Piwik-ArchiveSite
 * Version: 0.1.1
 */
?><?php
/**
 *
 * @author iMarkus
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 */

namespace Piwik\Plugins\ArchiveSite;

use Piwik\Common;
use Piwik\Container\StaticContainer;
use Psr\Log\LoggerInterface;
use Piwik\Plugin;
use Exception;

 
if (defined( 'ABSPATH')
&& function_exists('add_action')) {
    $path = '/matomo/app/core/Plugin.php';
    if (defined('WP_PLUGIN_DIR') && WP_PLUGIN_DIR && file_exists(WP_PLUGIN_DIR . $path)) {
        require_once WP_PLUGIN_DIR . $path;
    } elseif (defined('WPMU_PLUGIN_DIR') && WPMU_PLUGIN_DIR && file_exists(WPMU_PLUGIN_DIR . $path)) {
        require_once WPMU_PLUGIN_DIR . $path;
    } else {
        return;
    }
    add_action('plugins_loaded', function () {
        if (function_exists('matomo_add_plugin')) {
            matomo_add_plugin(__DIR__, __FILE__, true);
        }
    });
}

class ArchiveSite extends \Piwik\Plugin
{
    /**
     * @see Piwik_Plugin::getListHooksRegistered
     */
    public function getListHooksRegistered()
    {
        return array(
            'AssetManager.getJavaScriptFiles'        => 'getJsFiles',
            'AssetManager.getStylesheetFiles'        => 'getStylesheetFiles',
            'Translate.getClientSideTranslationKeys' => 'getClientSideTranslationKeys'
        );
    }
	
	/**
     * Plugin activate
     * 
     */
    public function activate()
    {
	    $logger = StaticContainer::get('Psr\Log\LoggerInterface');
	    $logger->info('Plugin ArchiveSite activated');
    }

	/**
     * Plugin deactivate
     * 
     */
    public function deactivate()
    {
        $logger = StaticContainer::get('Psr\Log\LoggerInterface');
        $logger->info('Plugin ArchiveSite deactivated.');
    }
	
	/**
     * Adds required JS files
     * @param $jsFiles
     */
    public function getJsFiles(&$jsFiles)
    {
        $jsFiles[] = "plugins/ArchiveSite/javascripts/archivesite.controller.js";
    }
	
	/**
     * Adds required CSS files
     * @param $stylesheets
     */
    public function getStylesheetFiles(&$stylesheets)
    {
        $stylesheets[] = "plugins/ArchiveSite/stylesheets/styles.less";
    }

    /**
     * Adds translation keys required in JS
     * @param $translationKeys
     */
    public function getClientSideTranslationKeys(&$translationKeys)
    {
        $translationKeys[] = "ArchiveSite_AllSegments";
        $translationKeys[] = "ArchiveSite_ArchiveSuccess";
        $translationKeys[] = "ArchiveSite_ArchiveAPIReturn";
    }
}
